import logging
from pathlib import Path
from watchdog.observers import Observer

logger = logging.getLogger(__name__)


class LogTailerObserver:
    """
    Subclasses must define the "watch_file" attribute
    """

    def __init__(self, handler):
        self.observer = Observer()
        self.handler = handler

    def start(self):
        watch_file = self.handler.get_watch_file()
        watch_file_path = Path(watch_file)

        try:
            self.observer.schedule(self.handler, watch_file, recursive=watch_file_path.is_dir())
            self.observer.start()
            logger.info(f'Starting observer for {watch_file}')
        except FileNotFoundError:
            logger.error(f'Unable to start observer for "{watch_file}" - file not found.')

    def stop(self):
        self.observer.stop()
        msg = f'{self.__class__.__name__} Observer stopped'
        logger.info(msg)

        try:
            self.observer.join(.25)
        except RuntimeError:
            logger.info(f'{self.__class__.__name__} Observer was never started')
            pass


__all__ = [
    'LogTailerObserver',
]
